@@ -120,12 +120,12 @@ class Entity:
         )
 
     def _create_mpc_wrapper(
-        self, file_pattern: str, use_graphql: bool, **kwargs
+        self, file_pattern: str, use_graphql: bool, filter_func: Callable = None, recursive: bool = None, **kwargs
     ) -> dict:
         if not file_pattern:
             mpc = self._create_mpc(**kwargs)
         else:
-            mpc = self._create_mpc_from_file(file_pattern)
+            mpc = self._create_mpc_from_file(file_pattern, filter_func=filter_func, recursive=recursive)
         return {"mpc": mpc, "use_graphql": use_graphql}
 
     def upsert(
